import streamlit as st
from PIL import Image

def app():
    st.title('Idli & Coco')
    image_path = os.path.join(os.path.dirname(__file__), 'idli_coco.jpg')
    image = Image.open(image_path)
    st.image(image, caption='Idli & Coco')

if __name__ == "__main__":
    app()


from setuptools import setup, find_packages

setup(
    name='idli_coco',
    version='1.1.3',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'streamlit',
    ],
    entry_points={
        'console_scripts': [
            'idli_coco = idli_coco.main:run',
        ],
    },
)